==> haskell-tasty-golden-2.3.2-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-golden.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-golden
version: 2.3.2
id: tasty-golden-2.3.2-5dFW7h6F5YQ7aNXFyENx9Q
key: tasty-golden-2.3.2-5dFW7h6F5YQ7aNXFyENx9Q
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka
homepage: https://github.com/feuerbach/tasty-golden
synopsis: Golden tests support for tasty
description:
    This package provides support for «golden testing».
    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.
    To get started with golden testing and this library, see
    <https://ro-che.info/articles/2017-12-04-golden-tests Introduction to golden testing>.
category: Testing
abi: 06dfd4804743d65514fb4619d000601f
exposed: True
exposed-modules:
    Test.Tasty.Golden Test.Tasty.Golden.Advanced
    Test.Tasty.Golden.Manage
hidden-modules: Test.Tasty.Golden.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-golden-2.3.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-golden-2.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/tasty-golden-2.3.2
hs-libraries: HStasty-golden-2.3.2-5dFW7h6F5YQ7aNXFyENx9Q
depends:
    base-4.11.1.0 tasty-1.1.0.3-47QwUInRtOzF3zSlr6CCJg
    bytestring-0.10.8.2 process-1.6.3.0 mtl-2.2.2
    optparse-applicative-0.14.2.0-AIlRv3oqRnL3QRzeNDiQLx filepath-1.4.2
    temporary-1.3-9oQzo4JVNP7CXkKVrv2cKm
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO deepseq-1.4.3.0
    containers-0.5.11.0 directory-1.3.1.5
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             tasty-1.1.0.3-47QwUInRtOzF3zSlr6CCJg=2e6555b026876c59a316d2124bf273ef
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             optparse-applicative-0.14.2.0-AIlRv3oqRnL3QRzeNDiQLx=122fe1d9115c41827cd61505838d2602
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             temporary-1.3-9oQzo4JVNP7CXkKVrv2cKm=ea3af39ce8ca8ee514ec8c391cc2de11
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=32776142fda961cc693aa4db742773f9
haddock-interfaces: /usr/share/doc/haskell-tasty-golden/html/tasty-golden.haddock
haddock-html: /usr/share/doc/haskell-tasty-golden/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-golden-2.3.2-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-golden.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-golden
version: 2.3.2
id: tasty-golden-2.3.2-5TTwDNEKzvN5NT0vjoVNcM
key: tasty-golden-2.3.2-5TTwDNEKzvN5NT0vjoVNcM
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka
homepage: https://github.com/feuerbach/tasty-golden
synopsis: Golden tests support for tasty
description:
    This package provides support for «golden testing».
    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.
    To get started with golden testing and this library, see
    <https://ro-che.info/articles/2017-12-04-golden-tests Introduction to golden testing>.
category: Testing
abi: 0e093cbd9cb02fa33b47cf0d7534d214
exposed: True
exposed-modules:
    Test.Tasty.Golden Test.Tasty.Golden.Advanced
    Test.Tasty.Golden.Manage
hidden-modules: Test.Tasty.Golden.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-golden-2.3.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-golden-2.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/tasty-golden-2.3.2
hs-libraries: HStasty-golden-2.3.2-5TTwDNEKzvN5NT0vjoVNcM
depends:
    base-4.11.1.0 tasty-1.1.0.3-KUFSSP3U4ny9AQF2XUXxIK
    bytestring-0.10.8.2 process-1.6.3.0 mtl-2.2.2
    optparse-applicative-0.14.2.0-5kDvpaFLtQNB16vTZLs8dg filepath-1.4.2
    temporary-1.3-JxV7dEpTppeGXaZqSEN7re
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO deepseq-1.4.3.0
    containers-0.5.11.0 directory-1.3.1.5
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             tasty-1.1.0.3-KUFSSP3U4ny9AQF2XUXxIK=b3b38fe9dbf8881a7eed1fb4b5bf8074
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             optparse-applicative-0.14.2.0-5kDvpaFLtQNB16vTZLs8dg=ae7f0ef22284c6d85efc629be435c88e
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             temporary-1.3-JxV7dEpTppeGXaZqSEN7re=771c55cbbdd451ecc55a6b35f8825c75
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=32776142fda961cc693aa4db742773f9
haddock-interfaces: /usr/share/doc/haskell-tasty-golden/html/tasty-golden.haddock
haddock-html: /usr/share/doc/haskell-tasty-golden/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
